@@ -1,6 +1,10 @@
 cran_url <- function(protocol = "https") {
   protocol <- match.arg(protocol, c("https", "http", "ftp"))
   if (identical(protocol, "ftp")) {
+    warning(
+      "The FTP protocol on the CRAN servers will soon be deprecated ",
+      "because they are insecure. Consider using HTTPS."
+    )
     return("ftp://cran.r-project.org")
   }
 
