@@ -1,6 +1,6 @@
 test_that("Documentation is correct", {
   skip_on_cran()
-  skip_on_travis()
+  skip_on_ci()
 
   ## make sure all folders investigated are correct
   expect_silent(res <- cran_incoming())
@@ -16,7 +16,7 @@ test_that("Documentation is correct", {
       version = c("package_version", "numeric_version"),
       cran_folder = "character",
       time = c("POSIXct", "POSIXt"),
-      size = "integer"
+      size = "character"
     )
   )
 })
@@ -29,7 +29,7 @@ test_that("only character strings are provided", {
 
 test_that("filtering works", {
   skip_on_cran()
-  skip_on_travis()
+  skip_on_ci()
   res <- cran_incoming()
   pkg_test <- sample(res$package, 5L)
   res_test <- cran_incoming(pkg = pkg_test)
@@ -38,7 +38,7 @@ test_that("filtering works", {
 
 test_that("specifying folders works", {
   skip_on_cran()
-  skip_on_travis()
+  skip_on_ci()
   res <- cran_incoming(folders = "archive")
   expect_true(nrow(res) > 1 && all(res$cran_folder == "archive"))
   res2 <- cran_incoming(folders = c("inspect", "pending"))
